OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Zadaný operátor je neplatný",
    "The given regular expression is invalid" : "Zadaný regulárny výraz je neplatný",
    "The given file size is invalid" : "Zadaná veľkosť súboru je neplatná",
    "The given tag id is invalid" : "Zadaný identifikátor štítku je neplatný",
    "The given IP range is invalid" : "Zadaný rozsah IP je neplatný",
    "The given IP range is not valid for IPv4" : "Zadaný IP rozsah nie je platný pre IPv4",
    "The given IP range is not valid for IPv6" : "Zadaný IP rozsah nie je platný pre IPv6",
    "The given time span is invalid" : "Zadané časové rozpätie nie je platné",
    "The given start time is invalid" : "Zadaný čas začatia nie je platný",
    "The given end time is invalid" : "Zadaný čas ukončenia nie je platný",
    "The given group does not exist" : "Zadaná skupina neexistuje",
    "File" : "Súbor",
    "File created" : "Vytvorený súbor",
    "File updated" : "Aktualizovaný súbor",
    "File renamed" : "Premenovaný súbor",
    "File deleted" : "Zmazaný súbor",
    "File accessed" : "Prístup k súboru",
    "File copied" : "Kopírovaný súbor",
    "Tag assigned" : "Priradený štítok",
    "Someone" : "Niekto",
    "%s created %s" : "%s vytvorené %s",
    "%s modified %s" : "%s zmenené %s",
    "%s deleted %s" : "%s vymazané %s",
    "%s accessed %s" : "%s pristupené k %s",
    "%s renamed %s" : "%s premenované %s",
    "%s copied %s" : "%s skopírovné %s",
    "%s assigned %s to %s" : "%s priradené %s k %s",
    "Operation #%s does not exist" : "Operácia #%s neexistuje",
    "Entity %s does not exist" : "Entita%s neexistuje",
    "Entity %s is invalid" : "Entita %s je neplatná",
    "No events are chosen." : "Neboli vybrané žiadne udalosti.",
    "Entity %s has no event %s" : "Entita %s nemá udalosť %s",
    "Operation %s does not exist" : "Operácia %s neexistuje",
    "Operation %s is invalid" : "Operácia #%s nie je platná",
    "At least one check needs to be provided" : "Musí sa vykonať aspoň jedna kontrola",
    "The provided operation data is too long" : "Poskytnuté prevádzkové údaje sú príliš dlhé",
    "Invalid check provided" : "Poskytnutá neplatná kontrola",
    "Check %s does not exist" : "Kontrola %s neexistuje",
    "Check %s is invalid" : "Kontrola %s je neplatná",
    "Check %s is not allowed with this entity" : "Kontrola %s nie je pre túto entitu povolená",
    "The provided check value is too long" : "Zadaná kontrolná hodnota je príliš dlhá",
    "Check #%s does not exist" : "Kontrola #%s neexistuje",
    "Check %s is invalid or does not exist" : "Kontrola %s je neplatná alebo neexistuje",
    "Flow" : "Flow (tok)",
    "Nextcloud workflow engine" : "Služba Nextcloud pre pracovné postupy",
    "Select a filter" : "Vybrať filter",
    "Select a comparator" : "Vybrať porovnávač",
    "Select a file type" : "Vyberte typ súboru",
    "e.g. httpd/unix-directory" : "napr. adresár  httpd/unix",
    "Folder" : "Priečinok",
    "Images" : "Obrázky",
    "Office documents" : "Dokumenty Office",
    "PDF documents" : "Dokumenty PDF",
    "Custom MIME type" : "Vlastný typ MIME",
    "Custom mimetype" : "Vlastné typy mime",
    "Please enter a valid time span" : "Zadajte prosím platné časové rozmedzie",
    "Select a request URL" : "Vybrať URL požiadavku",
    "Files WebDAV" : "WebDAV súbory",
    "Custom URL" : "Vlastná URL",
    "Select a user agent" : "Zvoliť užívateľského agenta",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Desktopový klient",
    "Thunderbird & Outlook addons" : "Doplnky pre Thunderbird a Outlook",
    "Custom user agent" : "Vlastný agent užívateľa",
    "At least one event must be selected" : "Musí byť vybraná aspoň jedna udalosť",
    "Add new flow" : "Pridať nový tok",
    "When" : "Keď",
    "and" : "a",
    "Add a new filter" : "Pridať nový filter",
    "Cancel" : "Zrušiť",
    "Delete" : "Zmazať",
    "The configuration is invalid" : "Konfigurácia je neplatná",
    "Active" : "Aktívne",
    "Save" : "Uložiť",
    "Available flows" : "Dostupné toky",
    "For details on how to write your own flow, check out the development documentation." : "Podrobnosti o tom, ako vytvárať vlastné toky, nájdete v dokumentácii pre vývojárov.",
    "More flows" : "Ďalšie toky",
    "Browse the App Store" : "Prehliadanie obchodu s aplikáciami",
    "Show less" : "Zobraziť menej",
    "Show more" : "Zobraziť viac",
    "Configured flows" : "Nastavené toky",
    "Your flows" : "Vaše toky",
    "matches" : "súhlasí",
    "does not match" : "nesúhlasí",
    "is" : "je",
    "is not" : "nie je",
    "File name" : "Názov súboru",
    "File MIME type" : "MIME typ súboru",
    "File size (upload)" : "Veľkosť súboru (upload)",
    "less" : "menej",
    "less or equals" : "menej alebo rovné",
    "greater or equals" : "viac alebo rovné",
    "greater" : "viac",
    "Request remote address" : "Vyžiadať vzdialenú adresu",
    "matches IPv4" : "súhlasí s IPv4",
    "does not match IPv4" : "nesúhlasí s IPv4",
    "matches IPv6" : "súhlasí s IPv6",
    "does not match IPv6" : "nesúhlasí s IPv6",
    "File system tag" : "Štítok súborového systému",
    "is tagged with" : "je označený",
    "is not tagged with" : "nie je označený",
    "Request URL" : "Vyžiadať URL",
    "Request time" : "Čas požiadavky",
    "between" : "medzi",
    "not between" : "nie je medzi",
    "Request user agent" : "User agent požiadavky",
    "is member of" : "Je členom",
    "is not member of" : "Nie je členom",
    "User group membership" : "Členstvo v skupine používateľov"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
